/***************************************************************************
* k1types_audio.h Contains definitions of K1 system related to audio.
*                 
*
* Antti Pulakka, Juha Kuusama, Kuusama Design Oy
*
* $Id$
* $HeadURL$
***************************************************************************/
#ifndef K1TYPES_AUDIO_H
#define K1TYPES_AUDIO_H

#define HW_I2SREV 0x50
#define HW_CONTROL_FPGA_REV_C 0x40
#define HW_CONTROL_FPGA_REV_D 0x50

/***************************************************************************/
/*  K1 audiotype defines                                                   */
/*  - Audiotypes are used when enabling/disabling audio input/output.      */
/*    Used mainly as arguments to audio library.                           */
/***************************************************************************/

/* Audio commands defined (used as types of CIE_AUDIOCMD k1events, more
   specificly k1event.data.audcmd.command) */
   
// Test program is looking for the following line, do not change it!!
//***_K1_audiocommand_defines_***
#define AUD_VOLUMEUP    100
#define AUD_VOLUMEDOWN  101
#define AUD_VOLUME      102
#define AUD_USERMUTE		103		// 0=on, 1= off, 2 toggle

// softmute on: fast, relatively clean temporary mute for mode and
// input changes etc; wait 15ms after turning on before doing anything
// that affects audio. Turn off when you know audio is again clean
#define AUD_SOFTMUTEON	104
#define AUD_SOFTMUTEOFF	105

#define AUD_CHANNELTRIM 110
#define AUD_SHOWTRIMS   111
#define AUD_LFEGAIN	  	112
#define AUD_SHOWLFEGAIN 113
#define AUD_REFLEVEL 		114
#define AUD_SHOWREFLEVEL 115

#define AUD_DSPWRITE		201		// 2xx for audiousd internal use only
#define AUD_DSPREAD			202
#define AUD_DSPRESET		203
#define AUD_DSPINT  		205
#define AUD_DSPINTSTAT	206
#define AUD_DSP_AUTODETECT  207

#define AUD_INIT				302
#define AUD_SETINPUT		303
#define AUD_SETADGAIN		304
#define AUD_SETMCADGAIN		305
#define AUD_MCINSUBLOW	306

#define AUD_SRCWRITE      401
#define AUD_SRCREAD       402
#define AUD_DININT 			405
#define AUD_DININTSTAT	  406
#define AUD_DINWRITE		  407
#define AUD_DINREAD			408
#define AUD_RESETDIN		  409

#define AUD_RESETSETTINGS 501
#define AUD_SAVESETTINGS 502

#define AUD_SHOWDELAYS	601
#define AUD_SETDELAY		602
#define AUD_SPKRCONF		604
#define AUD_MAINX				605
#define AUD_CENX				606
#define AUD_SUBX				607
#define AUD_SURRX				608
#define AUD_BACKX				609

#define AUD_SETNOISE		701
#define AUD_VIDEOPROCDELAY		702
#define AUD_LIPSYNCDELAY		703

// IRC stuff
#define AUD_SETMEASURE        704
#define AUD_IRCGAIN           705
#define AUD_IRCDELAY          706
#define AUD_IRCRESULTS        707


#define AUD_SETRELAY		801
#define AUD_CLEARRELAY	802
#define AUD_HDMIMUTE		803
#define AUD_HDMIUNMUTE	804
		#define AUD_HDMIUNMUTE_FS       0
		#define AUD_HDMIUNMUTE_MCLK     1

#define AUD_PLIIWIDTH				901
#define AUD_PLIIDIMENSION		902
#define AUD_DDDYNAMICS			903
#define AUD_NEOWIDE  			904   // !0 = on
#define AUD_NEOCGAIN 			905   // Center gain in music mode, 0..1.0 = 0x0 .. 0x7fffffff
#define AUD_PLIIPANORAMA		906 // 0=off, 1=on
#define AUD_DOLBYHDDYNAMICS			907
#define AUD_DSURMODCONTROL			908
#define AUD_LATENIGHT			909

#define AUD_SETMODE			    1001
#define AUD_CLEARUSEDMODES  1002
#define AUD_USEPREFMODES    1003

// tone
#define AUD_BASS			    1101
#define AUD_BASSUP			  1102
#define AUD_BASSDOWN			1103
#define AUD_TREBLE			    1104
#define AUD_TREBLEUP			  1105
#define AUD_TREBLEDOWN			1106

#define AUD_TEST        10001
#define AUD_DEBUG				10002
#define AUD_FULLDEBUG   10003
#define AUD_STATUS			10004
#define AUD_FULLDEBUGOFF   10005
#define AUD_SPDIFTOHDMI 10006
#define AUD_DSPCOMM 10007

#define AUD_SETZONEIN   11001
#define AUD_ZONEVOL     11002
#define AUD_ZONEMUTE    11003
#define AUD_ZONEVOLUP   11004
#define AUD_ZONEVOLDOWN 11005

#define AUD_RESETRP     12002

#define AUD_SETHDMIOUTGAIN  13001

// This event is sent by HDMI driver when signal is stable on its side.
#define AUD_HDMI_SIGNAL_TYPE  14001 
// parameters: #1: 0= PCM, 1= packed data
// #2: sample rate K1HDMI_FSxx as defined in k1hdmi.h 

// This event is sent by HDMI driver when audio info frame is received.
#define AUD_HDMI_AIF          14002 
// Audio info frame event parameters: 
// #1: stream type (defines are in k1hdmilib.h)
// #2: channels (0 is unknown, param value + 1 = channels)
// #3: sample rate (defines are in k1hdmilib.h)
// #4: bits (defines are in k1hdmilib.h)
// #5: speaker setup (more information CEA-861-E page 51 and 52)
// #6: Level shift (more information from CEA-861-E document page 53)
// #7: Down-mix inhibit flag (more information from CEA-861-E document page 53)
// #8: LFE playback level (more information from CEA-861-E document page 54)


//***_K1_audiocommand_defines_end***
// Do not change the previous line either!

// =======================================
// events set by the audio usd 
// =======================================

#define NEW_MODE_EVENT				99001		// sent when system swithced to a new processing mode
#define NEW_MODELIST_EVENT		99002		// sent when system has updated the mode list
#define NEW_USERVOLUME_EVENT	99003		// sent when user volume setting changed
#define NEW_THX_STATUS_EVENT	99004
#define NEW_LFE_TRIM_EVENT		99005
#define NEW_ZONEUSERVOLUME_EVENT 99006
#define INVALID_MODE_EVENT   99007    // sent when the system is asked for a processing mdoe that is not valid right now
#define NEW_LIPSYNCDELAY_EVENT		99008
#define RP_RESET_DONE_EVENT		99009
#define NEW_TONEVAL_EVENT				99010		// sent when new tone control values are in effect

// =======================================
// D1 audioboard (hw_version_A) relays and control bits 
// =======================================
// these were in wrong place, and should not be visible outside k1audiousd.
// k1audiousd is the only driver that knows and should know the differences 
// between audio hardware revisions.


// ===========================================================
// Hardware properties (no of inputs etc)
// ===========================================================

/* Number of audio inputs/outputs */
//#define A2CH_INCOUNT    6
//#define A2CH_OUTCOUNT   2  /* Zone outputs */
//#define A8CH_INCOUNT    1
//#define A8CH_OUTCOUNT   0
//#define DIGITAL_INCOUNT   8
//#define DIGITAL_OUTCOUNT  0
//#define DHDMI_INCOUNT   1

// NOENTRY is valid for audiotypes also. 
// 0 here means the input is not present on this hardware
// xxx_FIRST .. xxx_LAST are the physical limits of the K1 platform,
// not necessarily present in a given product

#define NO_INPUT	0

// Analog audio, numerated
#define A2CH_FIRST		0x0100		// do not set this to 0!
#define A2CH            0x0100 // Type declaration, used by UI
#define A2CH1					0x0100		// stereo audio in 1
#define A2CH2					0x0101		// stereo audio in 2
#define A2CH3					0x0102		// stereo audio in 3
#define A2CH4					0x0103		// stereo audio in 4
#define A2CH5					0x0104		// stereo audio in 5
#define A2CH6  		    0x0105		// stereo audio in 6
#define A2CH7					0x0106		// stereo audio in 7
#define A2CH8					0x0107		// stereo audio in 8
#define A2CH9					0x0108		// phono
#define A2CH10				0x0109		// XLR 1
#define A2CH11				0x010a		// XLR 2
#define A2CH12				0x010b		// mic
#define A2CH13  			0x010c		// front (although MX150 doesn't have an input on front)
#define A2CH14				0x010e		// L&R of multichannel input
#define A2CH_LAST			0x010e		// do not set this to 0!

// symbolic names
#define AIN_PHONO     A2CH9
#define AIN_XLR1      A2CH10  
#define AIN_XLR2      A2CH11
#define AIN_MIC       A2CH12
#define AIN_FRONT     A2CH13
#define AIN_LR_OF_MC  A2CH14

// multichannel AD
#define A8CH_FIRST		0x0200		// do not set this to 0!
#define A8CH            0x0200 // Type declaration, used by UI
#define A8CH1					0x0200
#define A8CH_LAST			0x0200		// do not set this to 0!

// Digital inputs
#define DIGITAL_FIRST				0x0300			// do not set this to 0!
#define DIGITAL							0x0300 // Type declaration, used bu UI
#define DIGITAL_AES_EBU			0x0300			// AES_EBU
#define DIGITAL_COAX1				0x0301      // coax 1
#define DIGITAL_COAX2				0x0302      // coax 2
#define DIGITAL_COAX3				0x0303      // coax 3
#define DIGITAL_COAX4				0x0304      // coax 4
#define DIGITAL_OPT1				0x0305      // opt 1
#define DIGITAL_OPT2				0x0306      // opt 2 
#define DIGITAL_OPT3				0x0307      // opt 3
#define DIGITAL_OPT4				0x0308      // opt 4
#define DIGITAL_FRONT				0x0309      // front panel
#define DIGITAL_LAST		0x0309			// do not set this to 0!

// HDMI
#define HDMI_IN   0x0501		// have only one of these
#define DHDMI     0x0500 /* Digital from HDMI */
#define DHDMI1    0x0501

// CPU
#define CPU_IN    0x0601		// have only one of these
#define DCPU      0x0600   /* Digital from main CPU */
#define DCPU1     0x0601

#define NOISE_GEN  			0x0700		  // do not select directly
#define DIST_MIC        0x0701      // do not select directly

// ===========================================================


// ===========================================================
// i2s sources
// ===========================================================

#define I2S_AD2 		0
#define I2S_DIN			1
#define I2S_CPU			2
#define I2S_HDMI		3
#define I2S_AD6 		4
#define I2S_IRC 		5
// control bits in the i2s control register
#define DIN_TO_CSDIN		0x20
#define AD6HIGHGAIN		0x40



// ===========================================================
// zone sources
// ===========================================================
#define ZONE_NO_INPUT    0     
#define ZONE_AN1    1     // RCA analog inputs 1
#define ZONE_AN2    2
#define ZONE_AN3    3
#define ZONE_AN4    4
#define ZONE_AN5    5
#define ZONE_AN6    6
#define ZONE_AN7    7
#define ZONE_AN8    8     // ..to 8
#define ZONE_XLR1   9
#define ZONE_XLR2   10
#define ZONE_FRONT  11     // front panel analog connector
#define ZONE_PHONO  12


#endif
